<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author qezwan <qezwan@gmail.com>
 * @author Wrya <wryaali33@gmail.com>
 */
$lang['menu']                  = 'سازدانی ڕێکخستنەکان';
$lang['error']                 = 'رێکخستنەکان  نوێ نەکرانەوە بەهۆی بەهایەکی نادروست، تکایە پێداچوونەوە بە گۆڕانکاریەکانت دا بکە و دووبارە بینێرە.
                       <br/>بەهای نادروست نیشان دەدرێت کە بە سنووری سوور دەورەدراوە.';
$lang['updated']               = 'رێکخستنەکان بە سەرکەوتوویی نوێکرانەوە.';
$lang['nochoice']              = '(هیچ بژاردەیەکی تر لەبەردەستدا نیە)';
$lang['locked']                = 'ناتوانرێت فایلی ڕێکخستنەکان نوێبکرێتەوە، ئەگەر ئەمە بێ مەبەست بێت، <br/>
                       دڵنیابە لەوەی ناوی فایلی ڕێکبەندەکانی ناوخۆ و مۆڵەتەکان ڕاستن.';
$lang['danger']                = 'مەترسی: گۆڕینی ئەم هەڵبژاردنە لەوانەیە ویکی و لیستی شێوەپێدانەکەت ناتوانرێت دەست پێبکات.';
$lang['warning']               = 'ئاگاداری: گۆڕینی ئەم هەڵبژاردنە لەوانەیە ببێت بە هۆی ڕەفتارێکی نامەبەست.';
$lang['security']              = 'ئاگاداری پاراستن: گۆڕینی ئەم هەڵبژاردنە لەوانەیە مەترسیەکی ئەمنی پێشکەش بکات.';
$lang['_configuration_manager'] = 'بەڕێوەبەری شێوەپێدان';
$lang['_header_dokuwiki']      = 'دۆکوویکی';
$lang['_header_plugin']        = 'پێوەکراو';
$lang['_header_template']      = 'ڕووخسار';
$lang['_header_undefined']     = 'ڕێکبەندە پێناسە نەکراوەکان';
$lang['_basic']                = 'بنەڕەتی';
$lang['_display']              = 'پیشان بدە';
$lang['_authentication']       = 'سەلماندن';
$lang['_anti_spam']            = 'دژە-سپام';
$lang['_editing']              = 'دەستکاریکردن';
$lang['_links']                = 'بەستەرەکان';
$lang['_media']                = 'میدیا';
$lang['_notifications']        = 'ئاگانامە';
$lang['_syndication']          = 'سەندیکا (RSS)';
$lang['_advanced']             = 'پێشکەوتوو';
$lang['_network']              = 'تۆڕ';
$lang['_msg_setting_undefined'] = 'دانانی مێتاداتا';
$lang['_msg_setting_no_class'] = 'پۆلی ڕێکخستن نیە';
$lang['_msg_setting_no_known_class'] = 'دانانی پۆل بەردەست نیە.';
$lang['_msg_setting_no_default'] = 'هیچ بەهایەکی گریمانەیی نیە.';
$lang['title']                 = 'ناونیشانی ویکی ئاکا. ناوی ویکیی ەکەت';
$lang['start']                 = 'ناوی لاپەڕە بۆ بەکارهێنانی وەک خاڵی سەرەتا بۆ هەر بۆشایی ناوێک';
$lang['lang']                  = 'زمانی ڕووکار';
$lang['template']              = 'ڕووکاری ئاکا. دیزاینی ویکی';
$lang['tagline']               = '(تاگلاین (ئەگەر تێمپلەیت پشتگیری بکات';
$lang['sidebar']               = 'ناوی لاتەنیشت لاپەڕە (ئەگەر تێمپلەیت پشتگیری بکات), خانەی بەتاڵ شریتی لالەکاردەکەوێ';
$lang['license']               = 'دەبێت ناوەڕۆکەکەت لە ژێر کام مۆڵەتدا بڵاوبکرێتەوە؟	';
$lang['savedir']               = 'دایەرێکتۆری بۆ هەڵگرتنی داتا	';
$lang['basedir']               = 'ڕێڕەوی سێرڤەر (eg. <code>/dokuwiki/</code>). چۆڵی بە جێبهێڵە بۆ دۆزینەوەی خۆکار.';
$lang['baseurl']               = 'URL ی سێرڤەر (eg. <code>http://www.yourserver.com</code>) چۆڵی بە جێبهێڵە بۆ دۆزینەوەی خۆکار.';
$lang['cookiedir']             = 'ڕیگای کوکی، چۆڵی بەچێبهێڵە بۆ بنەمای خۆی';
$lang['dmode']                 = 'مۆدی دروست کردنی دایەرێکتۆری';
$lang['fmode']                 = 'دۆخی دروستکردنی فایل';
$lang['allowdebug']            = 'ڕێگەبدە بە هەڵباککردن. <b> ناچالاک کردن ئەگەر پێویست نەبوو!</b>';
$lang['recent']                = 'ژمارەی تێکردنەکان بۆ هەر پەڕەیەک لە گۆڕانکاریەکانی ئەم دواییەدا';
$lang['recent_days']           = '(چەند گۆڕانکاری ئەم دواییە بۆ هێشتنەوەی (ڕۆژەکان';
$lang['breadcrumbs']           = 'ژمارەی پارچە نانەکان دانانی بۆ 0 بۆ ناچالاککردن.';
$lang['youarehere']            = '(بەکارهێنانی نانی نانی هەرەمی (لەوانەیە بتەوێت ئەم هەڵبژاردنەی سەرەوە لە کار بخەیت دواتر';
$lang['fullpath']              = 'دەرکردنی ڕێگای تەواوی پەڕەکان لە ژێرپەڕە';
$lang['typography']            = 'ئایا گۆڕینی جۆری -ئێڵپۆگرافیک بکە';
$lang['dformat']               = 'فۆرماتی بەروار (بڕوانە PHP \'s <a href="http://php.net/strftime">strftime</a> function)';
$lang['signature']             = 'چی بکەیت بە دوگمەی ئیمزا لە سەرنووسەر';
$lang['showuseras']            = 'چی پیشان بدرێت کاتێک بەکارهێنەرەکە نیشان دەدات کە دوایین جار پەڕەیەکی بژارکردووە';
$lang['toptoclevel']           = 'ئاستی سەرەوە بۆ ریزبەندی بابەتەکان';
$lang['tocminheads']           = 'کەمترین بڕی مانشێت کە دیاری دەکات کە ئایا تۆک بنیات نراوە';
$lang['maxtoclevel']           = 'بەرزترین ئاست بۆ ریزبەندی بابەتەکان';
$lang['maxseclevel']           = 'بەرزترین ئاستی بژارکردنی بەش';
$lang['camelcase']             = 'بەکارهێنانی کەیسی وشتر بۆ بەستەرەکان';
$lang['deaccent']              = 'چۆن ناوی لاپەڕەکان خاوێن بکەوە';
$lang['useheading']            = 'یەکەم سەردێڕ بۆ ناوی لاپەڕەکان بەکاربهێنە';
$lang['sneaky_index']          = 'بە گریمانەیی، DokuWiki هەموو بۆشاییناوەکان لە نەخشەی سایتەکە پیشان دەدات. چالاککردنی ئەم هەڵبژاردنە ئەو کەسانە دەشارێتەوە کە بەکارهێنەر مۆڵەتەکانی خوێندنەوەی نیە. ئەمە لەوانەیە ببێتە هۆی شاردنەوەی بۆشایی لاوەکی توانای چوونەژورەوەی هەبێت کە لەوانەیە ئیندێکس ەکە بەکارنەهیێت لەگەڵ هەندێک ڕێکخستنی ACL.';
$lang['hidepages']             = 'شاردنەوەی پەڕەکان کە هاوچەوچەن لەگەڵ ئەم دەربڕینە ئاساییە لە گەڕان، نەخشەی سایت ەکە و ئیندێکسە ئۆتۆماتیکیەکانی تر';
$lang['useacl']                = 'بەکارهێنانی لیستەکانی کۆنترۆڵی چوونەژورەوە';
$lang['autopasswd']            = 'تێپەڕوشە دروستکەری خۆکار';
$lang['authtype']              = 'Authentication backend';
$lang['passcrypt']             = 'شێوازی نهێنینهێنی';
$lang['defaultgroup']          = 'گرووپی بنەڕەت، هەموو بەکارهێنەرە نوێکان لەم گرووپەدا دابنرێ';
$lang['superuser']             = 'Superuser - group, بەکارهێنەر یان وێرکڕا لیستی جیاکراوە user1,@group1,user2 لەگەڵ گەیشتنی تەواو بۆ هەموو لاپەڕەکان و ئەرکەکان بەبێ گوێدانە ڕێکبەندەکانی ACL';
$lang['manager']               = 'بەڕێوەبەر - گرووپ، بەکارهێنەر یان بۆر لیستی جیاکراوەی user1,@group1,user2لەگەڵ دەستگەیشتن بە هەندێک ئەرکی بەڕێوەبردن';
$lang['profileconfirm']        = 'پشتڕاستکردنەوەی گۆڕانکاریەکانی پرۆفایل بە نهێنوشە';
$lang['rememberme']            = 'ڕێگەدان بە کۆکیزەکانی چوونە ژوورەوەی هەمیشەیی (لەبیرت بێت)';
$lang['disableactions']        = 'کردارەکانی دۆکوویکی لە کاربخە';
$lang['disableactions_check']  = 'پشکنین';
$lang['disableactions_subscription'] = 'ئابوونە/بەتاڵکردنی ئابوونە';
$lang['disableactions_wikicode'] = 'بینینی سەرچاوە/ناردن خاو';
$lang['disableactions_profile_delete'] = 'سڕینەوەی ئەژمێری تایبەت';
$lang['disableactions_other']  = 'کردارەکانی تر (کۆما جیاکراونەتەوە)';
$lang['disableactions_rss']    = 'XML سەندیکا (RSS)';
$lang['auth_security_timeout'] = '(کاتی تەواوبووی ئاسایشی ڕەسەنایەتی سەلماندن (چرکە';
$lang['securecookie']          = 'ئایا کۆکیزەکان لە ڕێگەی HTTPS دابندرێن تەنها لە ڕێگەی HTTPS ئەوە دەنێردرێن لەلایەن وێبگەڕەکە؟ ئەم هەڵبژاردنە لە کاربخە کاتێک تەنها چوونە ژوورەوەی ویکیەکەت پارێزراوە لەگەڵ SSL بەڵام گەڕانی ویکی بە ناپارێزراوی ئەنجام دراوە.';
$lang['remote']                = 'چالاککردنی سیستەمی API ی دوور. ئەمە ڕێگە بە کاربەرنامەکانی تر دەدات بۆ چوونە ژورەوەی ویکی لە ڕێگەی XML-RPC یان میکانیزمەکانی ترەوە.';
$lang['remoteuser']            = 'سنوردارکردنی دەستگەیشتنی API لەدوورەوە بۆ کۆمەڵە جیاکراوەکان بە کۆما یان بەکارهێنەرەکان کە لێرە دران. بە بەتاڵی بڕۆ بۆ پێدانی دەستگەیشتن بە هەموو کەسێک.';
$lang['usewordblock']          = 'بلۆککردنی سپام لەسەر بنەمای لیستی ووشە';
$lang['relnofollow']           = 'بەکارهێنانی rel="ugc nofollow" لەسەر بەستەری دەرەکی';
$lang['indexdelay']            = 'دواخستنی کات پێش پێڕستکردن (sec)';
$lang['mailguard']             = 'ناونیشانی ئیمەیلی نادیار';
$lang['iexssprotect']          = 'پشکنینی فایلە بارکراوەکان بۆ ئەگەری خراپی JavaScript یان HTML کۆد';
$lang['usedraft']              = 'بە شێوەیەکی ئۆتۆماتیکی ڕەشنووسێک لە کاتی بژارکردندا خزن بکە';
$lang['locktime']              = 'بەرزترین تەمەن بۆ فایلەکانی قوفڵ (چرکە)
';
$lang['cachetime']             = 'بەرزترین تەمەن بۆ حەشارگە (چرکە)
';
$lang['target____wiki']        = 'پەنجەرەی مەبەست بۆ لینکە ناوەکیەکان
';
$lang['target____interwiki']   = 'پەنجەرەی مەبەست بۆ لینکەکانی نێوان ویکی
';
$lang['target____extern']      = 'پەنجەرەی مەبەست بۆ بەستەری دەرەکی';
$lang['target____media']       = 'پەنجەرەی مەبەست بۆ لینکەکانی میدیا';
$lang['target____windows']     = 'پەنجەرەی مەبەست بۆ لینکی پەنجەرەکان';
$lang['mediarevisions']        = 'چالاککردنی پێداچوونەوەکانی میدیا؟';
$lang['refcheck']              = 'بپشکنە ئەگەر فایلی میدیا هێشتا لە بەکارهێناندایە پێش سڕینەوەی';
$lang['gdlib']                 = 'ڤێرژنی GD Lib';
$lang['im_convert']            = 'ڕێڕەو بۆ ئامڕازی گۆڕینی ImageMagick';
$lang['jpg_quality']           = 'کوالیتی پەستانەکانی JPG (0-100)';
$lang['fetchsize']             = '(گەورەترین قەبارە (بایت fetch.php لەوانەیە دابەزێنێت لە URLs دەرەکی, وەک. بۆ خەزنکردنی کاتی و گۆڕینی قەبارەی وێنە دەرەکیەکان.';
$lang['subscribers']           = 'ڕێگە بدە بە بەکارهێنەران بۆ بەشداری کردن لە گۆڕانکاریەکانی لاپەڕە بە ئیمەیڵ';
$lang['subscribe_time']        = 'کات دوای ئەوەی کە لیستەکانی بەشداریکردن و هەرس دەنێردرێن (چرکە) ؛ ئەمە دەبێت بچووکتر بێت لەو کاتەی کە لە recent_days.';
$lang['notify']                = 'هەمیشە ئاگاداری ەکانی گۆڕان بنێرە بۆ ئەم ناونیشانی ئیمەیڵە';
$lang['registernotify']        = 'هەمیشە زانیاری لەسەر بەکارهێنەرە تازە تۆمارکراوەکان بنێرە بۆ ئەم ناونیشانی ئیمەیڵە';
$lang['mailfrom']              = 'ناونیشانی ئیمەیڵی نێرەر بۆ بەکارهێنانی بۆ ئیمەیڵە ئۆتۆماتیکیەکان';
$lang['mailreturnpath']        = 'ناونیشانی ئیمەیڵی وەرگر بۆ ئاگانامەکانی نەگەیشتن';
$lang['mailprefix']            = 'پێشگری بابەتی ئیمەیڵ بۆ بەکارهێنانی بۆ ئیمەیڵە ئۆتۆماتیکیەکان. بە بەتاڵی جێبێڵبۆ بەکارهێنانی ناونیشانی ویکی';
$lang['htmlmail']              = 'ناردنی گەڕانی باشتر، بەڵام گەورەتر لە قەبارەی ئیمەیلەکانی فرەبەشی HTML. لەکارخستنی تەنها پۆستەکان بۆ دەقی سادە.';
$lang['sitemap']               = 'دروستکردنی نەخشەی سایتی گووگڵ ئەمە زۆرجار (لە رۆژدا). 0 بۆ ناچالاککردن';
$lang['rss_type']              = 'جۆری ڕاگەیەنەری XML';
$lang['rss_linkto']            = 'لینکەکانی فیدی XML بۆ';
$lang['rss_content']           = 'چی پیشان بدرێت لە ئایتمی فیدی XML؟';
$lang['rss_update']            = 'ماوەکانی نوێکردنەوەی ڕاگەیەنەری XML (sec)';
$lang['rss_show_summary']      = 'پوختەی پیشاندانی ڕاگەیەنەری XML لە ناونیشان';
$lang['rss_show_deleted']      = 'پیشاندانی کورتەکانی وێبی XML';
$lang['rss_media']             = 'دەبێت چ جۆرە گۆڕانکاریەک لە ڕاگەیەنەری XML دا ریزبەند بکرێت؟';
$lang['rss_media_o_both']      = 'هەردووک';
$lang['rss_media_o_pages']     = 'پەڕەکان	';
$lang['rss_media_o_media']     = 'میدیا';
$lang['updatecheck']           = 'پشکنینی نوێکردنەوەو ئاگاداریەکانی پاراستن؟ DokuWiki پێویستە پەیوەندی بکات update.dokuwiki.org بۆ ئەم تایبەتمەندیە.';
$lang['userewrite']            = 'بەکارهێنانی URLە جوانەکان';
$lang['useslash']              = 'بەکارهێنانی کەمکردن وەک جیاکەرەوەی بۆشایی ناو لە URL';
$lang['sepchar']               = 'جیاکەرەوەی وشەی ناوی لاپەڕە';
$lang['canonical']             = 'بەکارهێنانی URL ە تەواو قوونەکان';
$lang['fnencode']              = 'شێوازی کۆدکردنی ناوی فایلەکانی نا-ASCII.';
$lang['autoplural']            = 'پشکنینی فۆرمەکانی پلوراڵ لە لینکەکان';
$lang['compression']           = 'شێوازی گوشارکردن بۆ فایلە کەمکراوەکان';
$lang['gzip_output']           = 'بەکارهێنانی ناوەڕۆکی gzip-بەکۆدکردن بۆ xhtml';
$lang['compress']              = 'CSS و دەرکەتی جاڤاسکریپت';
$lang['cssdatauri']            = 'قەبارە لە بایت تا کام وێنە ئاماژە کراوە لە فایلەکانی CSS پێویستە بە ڕاست لە پەڕەی ستایلەکە بنچینەوە بۆ کەمکردنەوەی HTTP داواکاری سەرپەڕی سەروی. <code> 400 </code> بۆ <code> 600 </code> بایت بەهایەکی باشە . دانانی <code>0</code> بۆ ناچالاککردن.';
$lang['send404']               = 'بنێرە "HTTP 404/Page نەدۆزرایەوە" بۆ ئەو لاپەڕانەی کە ئێستا نین';
$lang['broken_iua']            = 'ئایا ignore_user_abort لە سیستەمەکەت دا تێکچووە؟ ئەمە لەوانەیە دەبێتە هۆی کارنەکردنی گەڕانی ئیندێکس. IIS+PHP/CGI ناسراوە بە شکاوی. بڕوانە <a href="http://bugs.dokuwiki.org/?do=details&amp;task_id=852">Bug 852</a> بۆ زانیاری زیاتر.';
$lang['xsendfile']             = 'سەرپەڕەی فایلی-X-Sendfile بەکاربێنە بۆ ئەوەی بهێڵیت وێبسێرڤەرفایلە ستاتیکەکان ڕادەست بکات؟ وێبسێرڤەرەکەت پێویستە پشتگیری ئەمە بکات.';
$lang['renderer_xhtml']        = 'نمایشی بۆ بەکارهێنانی بۆ سەرەکی (xhtml) دەرچوی ویکی';
$lang['renderer__core']        = '%s (ناوک دووکوویکی)';
$lang['renderer__plugin']      = '%s (پێوەکراو)';
$lang['search_nslimit']        = 'سنوور بۆ گەڕان بۆ ناوەکانی ئێستای X. کاتێک گەڕانێک لە لاپەڕەیەک لە بۆشاییەکی قوڵتردا ئەنجام دەدرێت، یەکەم بۆشایی ناوی X وەک فلتەر زیاد دەکرێت';
$lang['search_fragment']       = 'دیاریکردنی ڕەفتاری گەڕانی پارچە گریمانەیی';
$lang['search_fragment_o_exact'] = 'ڕێک';
$lang['search_fragment_o_starts_with'] = 'دەست پێدەکات بە';
$lang['search_fragment_o_ends_with'] = 'کۆتایی دێت بە';
$lang['search_fragment_o_contains'] = 'لەخۆدەگرێت';
$lang['trustedproxy']          = 'متمانە بە ناردنی پرۆکسی گونجاو لەگەڵ ئەم دەربڕینە ئاساییە دەربارەی ئای پی ڕاستەقینەی کڕیارکە ی ڕاپۆرت دەکەن. گریمانەیی هاوچەشنە لەگەڵ تۆڕە ناوخۆییەکان. بە بەتاڵی جێبێڵبە بۆ باوەڕ کردن بە نوێنەر.';
$lang['_feature_flags']        = 'ئاڵاکانی تایبەتمەندی';
$lang['defer_js']              = 'Defer javascript بۆ جێبەجێ کردن پاش ئەوەی HTML لاپەڕەکە شیکراوە. خێرای پەڕەی هەستپێکراو باشتر دەکات بەڵام دەکرێت ژمارەیەکی کەم لە پێوەکراوەکان بشکێنێ.';
$lang['dnslookups']            = 'DokuWiki بەدوای ناوی خانەخوێبگەڕێ بۆ ناونیشانی ئای پی دوور لە بەکارهێنەران کە لاپەڕە گۆڕانکاریدەکەن. ئەگەر ڕاژەکاری دی ان ئەی سی خاو یان کارنەکردنت هەیە یان ئەم تایبەتمەندیەت نەوێت، ئەم هەڵبژاردنە لە کاربخە';
$lang['jquerycdn']             = 'ئایا دەبێت فایلەکانی اسکریپتی jQuery و jQuery UI لە CDN دابەزێنرێت؟ ئەمە داواکاری ەکانی HTTP زیاد دەکات، بەڵام لەوانەیە فایلەکان خێراتر باربکەن و بەکارهێنەران لەوانەیە هەر ئێستا خەزنیان بکەن.';
$lang['jquerycdn_o_0']         = 'بێ CDN، تەنها گەیاندنی ناوخۆیی';
$lang['jquerycdn_o_jquery']    = 'CDN لە code.jquery.com';
$lang['jquerycdn_o_cdnjs']     = 'CDN لە cdnjs.com';
$lang['proxy____host']         = 'ناوی سێرڤەری پرۆکسی';
$lang['proxy____port']         = 'پۆرتی پرۆکسی';
$lang['proxy____user']         = 'ناوی بەکارهێنەری پرۆکسی';
$lang['proxy____pass']         = 'نهێنوشەی پرۆکسی';
$lang['proxy____ssl']          = 'SSL بەکاربێنە بۆ پەیوەندی کردن بە پڕۆکسی';
$lang['proxy____except']       = 'دەربڕینی ڕێک بۆ هاوگونجانی URL ەکان کە پێویستە پرۆکسی بۆ ی بپەڕێت.';
$lang['license_o_']            = 'هیچ هەڵنەبژێردرا';
$lang['typography_o_0']        = 'هیچ';
$lang['typography_o_1']        = 'بە لاگرتنی تاکە وتە';
$lang['typography_o_2']        = 'لەخۆگرتنی تاکە وتە (لەوانەیە هەمیشە کار نەبێت)';
$lang['userewrite_o_0']        = 'هیچ';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'ناوخۆیی دۆکوویکی';
$lang['deaccent_o_0']          = 'کوژاوەتەوە';
$lang['deaccent_o_1']          = 'لابردن جیاوازەکان';
$lang['deaccent_o_2']          = 'ڕۆمانز';
$lang['gdlib_o_0']             = 'GD Lib بەردەست نیە';
$lang['gdlib_o_1']             = 'وەشانی 1.x';
$lang['gdlib_o_2']             = 'خۆدۆزینەوە';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'ئەبستراکت';
$lang['rss_content_o_diff']    = 'دیفێکی یەکگرتوو';
$lang['rss_content_o_htmldiff'] = 'خشتەی جیاوازی فۆرماتکراو HTML';
$lang['rss_content_o_html']    = 'ناوەڕۆکی تەواوی پەڕەی HTML';
$lang['rss_linkto_o_diff']     = 'ڕوانگەی جیاواز';
$lang['rss_linkto_o_page']     = 'لاپەڕەی پێداچوونەوەکراو';
$lang['rss_linkto_o_rev']      = 'لیستی پێداچوونەوەکان';
$lang['rss_linkto_o_current']  = 'پەڕەی ئێستا';
$lang['compression_o_0']       = 'هیچ';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'بەکارمەهێنیت';
$lang['xsendfile_o_1']         = '(سەرپەڕی گشتی لایتپی دی (پێش بڵاوکردنەوەی ١.٥';
$lang['xsendfile_o_2']         = 'سەرپەڕی فایلی-X-پێوانەیی';
$lang['xsendfile_o_3']         = 'سەرپەڕەی سەرپەڕەی خاوەن بەشی Nginx X-Accel-Redirect';
$lang['showuseras_o_loginname'] = 'ناوی چوونەژوورەوە';
$lang['showuseras_o_username'] = 'ناوی تەواوی بەکارهێنەر';
$lang['showuseras_o_username_link'] = 'ناوی تەواوی بەکارهێنەر وەک لینکی بەکارهێنەری نێوان ویکی';
$lang['showuseras_o_email']    = 'ناونیشانی ئیمەیڵی بەکارهێنەر (بە گوێرەی رێکبەندەکانی پاسەوانی پۆستە ی یورلاکراوە)';
$lang['showuseras_o_email_link'] = 'ناونیشانی ئیمەیڵی بەکارهێنەر وەک ئیمەیل: link';
$lang['useheading_o_0']        = 'هەرگیز';
$lang['useheading_o_navigation'] = 'تەنها ڕێنیشاندەر';
$lang['useheading_o_content']  = 'تەنها ناوەڕۆکی ویکی';
$lang['useheading_o_1']        = 'هەمیشە';
$lang['readdircache']          = 'بەرزترین تەمەن بۆ کاتی خوێندنەوە (sec)';
